@@ -1,11 +1,8 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 
+const { Gio, St } = imports.gi;
 const Signals = imports.signals;
 
-const GLib = imports.gi.GLib;
-const Gio = imports.gi.Gio;
-const St = imports.gi.St;
-
 const ExtensionUtils = imports.misc.extensionUtils;
 const Main = imports.ui.main;
 
