@@ -1,10 +1,9 @@
 // -*- mode: js; js-indent-level: 4; indent-tabs-mode: nil -*-
 
-const Clutter = imports.gi.Clutter;
-const St = imports.gi.St;
-
 const UI = imports.testcommon.ui;
 
+const { Clutter, St } = imports.gi;
+
 function test() {
     let stage = new Clutter.Stage({ width: 640, height: 480 });
     UI.init(stage);
